#
# spec file for package xf86-video-qxl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Xspice is x86_64 only since spice-server is x86_64 only
%ifarch x86_64
%if %{suse_version} >= 1230
%bcond_without xspice
%else
%bcond_with xspice
%endif
%else
%bcond_with xspice
%endif

Name:           xf86-video-qxl
Version:        0.1.6
Release:        2.3
Summary:        QXL virtual GPU video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
Patch0:         Xspice-python3.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(libcacard)
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pciaccess) >= 0.10
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(spice-protocol) >= 0.12.2
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xf86dgaproto)
BuildRequires:  pkgconfig(xfont2)
BuildRequires:  pkgconfig(xorg-macros) >= 1.4
BuildRequires:  pkgconfig(xorg-server) >= 1.0.99.901
BuildRequires:  pkgconfig(xproto)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x
%x11_abi_videodrv_req

%description
qxl is an Xorg driver for QXL virtual GPU as found in the spice project.

%if %{with xspice}
%package -n    xorg-x11-server-Xspice
Summary:        XSpice is an X server that can be accessed by a Spice client
Group:          System/X11/Servers/XF86_4
%x11_abi_videodrv_req
BuildRequires:  pkgconfig(spice-server) >= 0.6.3

%description -n xorg-x11-server-Xspice
XSpice is both an X and a Spice server that can be accessed by a Spice client.
%endif

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
%if 0%{?with_xspice}
    --enable-xspice \
    --enable-ccid
%endif

make %{?_smp_mflags}

%install
%make_install
%if %{with xspice}
# FIXME: upstream installs this file by default, we install it elsewhere.
# upstream should just not install it and let dist package deal with
# doc/examples.
rm -f $RPM_BUILD_ROOT/usr/share/doc/xf86-video-qxl/spiceqxl.xorg.conf.example
%endif
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/qxl_drv.so

%if %{with xspice}
%files -n xorg-x11-server-Xspice
%defattr(-,root,root)
%doc COPYING README.xspice README.md examples/spiceqxl.xorg.conf.example
%{_bindir}/Xspice
%{_libdir}/xorg/modules/drivers/spiceqxl_drv.so
%dir %{_libdir}/pcsc/
%dir %{_libdir}/pcsc/drivers/
%dir %{_libdir}/pcsc/drivers/serial/
%{_libdir}/pcsc/drivers/serial/libspiceccid.so*
%endif

%changelog
* Mon Jan 29 2024 Stefan Dirsch <sndirsch@suse.com>
- Xspice-python3.patch
  * for python3 interpreter needs to be /usr/bin/python3
* Tue Jan 24 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 0.1.6
  * This release flushes out the last [checks calendar] ~6 years of
    patches that have been sitting on the master branch. Please see
    the git shortlog below for details.
- supersedes the following patches
  * Xspice-python3.patch
  * n_disable-surfaces-on-kms.patch
  * n_hardcode_libdrm_cflags.patch
  * u_fix-build-against-xserver-21_1.patch
* Sat May 14 2022 Stefan Dirsch <sndirsch@suse.com>
- remove "hardware" supplements; modeset is used now with KMS driver
* Mon Nov  1 2021 Stefan Dirsch <sndirsch@suse.com>
- u_fix-build-against-xserver-21_1.patch
  * fixes build aginst xorg-server 21.1; reson:
    commit 454b3a826edb5fc6d0fea3a9cfd1a5e8fc568747
    Author: Adam Jackson <ajax@redhat.com>
    Date:   Mon Jul 22 13:51:06 2019 -0400
    hw: Rename boolean config value field from bool to boolean
* Fri Jul 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded Requires on python >= 2.6
- Add Xspice-python3.patch:
  * Add support for Python 3, and run it under Python 3.
* Tue Jun 30 2020 Stefan Dirsch <sndirsch@suse.com>
- no longer ship xorg.conf sample file in /etc/X11; it's available
  as %%doc (boo#1173058)
* Sun Jan  1 2017 sndirsch@suse.com
- Update to version 0.1.5:
  * Bug fixes and performance improvements
- supersedes the following patches:
  * U_Check-for-either-xfont.pc-or-xfont2.pc.patch
  * U_Fix-compilation-with-newer-Xorg-versions.patch
  * U_qxl-use-pci-io.patch
  * U_xf86-video-qxl-spiceccid-build.patch
* Wed Nov 30 2016 sndirsch@suse.com
- U_Check-for-either-xfont.pc-or-xfont2.pc.patch
  * Check for either xfont.pc or xfont2.pc
- U_Fix-compilation-with-newer-Xorg-versions.patch
  * Fix compilation with newer Xorg versions
* Fri Jun 10 2016 sndirsch@suse.com
- renamed u_xf86-video-qxl-spiceccid-build.patch to
  U_xf86-video-qxl-spiceccid-build.patch, since the fix is already
  upstream (git #ebd5ef7c18d7c361a31d530b307d36217cc68428)
* Mon Jun  6 2016 dimstar@opensuse.org
- Add u_xf86-video-qxl-spiceccid-build.patch: Fix building of
  spiceccid: add the correct CFLAGS while building spiceccid. Issue
  is exposed by libcacard 2.5.2.
* Wed Apr 20 2016 sndirsch@suse.com
- U_qxl-use-pci-io.patch
  * Fix build on AArch64 by backporting upstream patch to use
    pci_io_write8 instead of outb
* Wed Nov 11 2015 sndirsch@suse.com
- added BuildRequires: pkgconfig(xfont) in order to fix build
  against xorg-server 1.18.0
* Tue Apr  7 2015 zaitor@opensuse.org
- Update to version 0.1.4:
  + Added smartcard support to XSpice.
  + Memleak fix which could cause X to run out of memory.
  + Expose randr properties for suggested display positions if
    kernel supports it.
- Add pkgconfig(libcacard) and pkgconfig(libpcsclite)
  BuildRequires and pass --enable-ccid to configure in order to
  build the new smartcard support.
- Add pkgconfig(libudev) BuildRequires: Build with udev support.
* Wed Nov  5 2014 sndirsch@suse.com
- xf86-video-qxl 0.1.3
  * bug fixes
* Fri Aug 29 2014 coolo@suse.com
- fix the use of build conditionals
* Fri Aug 29 2014 tiwai@suse.de
- n_disable-surfaces-on-kms.patch
  Disable the broken offscreen surfaces on KMS (bnc#894022)
* Mon Aug 25 2014 fcrozat@suse.com
- Build Xspice X server and driver (on openSUSE 12.3 and later),
  ship them a separate subpackage.
* Thu Jul 24 2014 sndirsch@suse.com
- Update to version 0.1.2:
  * Support for server managed fds
  * Xspice: use playback rate interface if available
  * Bugs fixed:
  - 1030531 - drm: restore cursor after resolution change
  - fix cursor2 support in older kernels
  - FD 79317 - prevent crash on dual head systems
* Thu Apr 24 2014 sndirsch@suse.com
- n_hardcode_libdrm_cflags.patch:
  * Hardcode libdrm cflags in order to enable KMS support
    (bnc#870501)
* Sun Oct 27 2013 sndirsch@suse.com
- Update to version 0.1.1:
  * KMS support
  * DFPS available to guest driver too
  * Xspice audio & agent support
  * GPL code removed (EDID)
  * Warnings squash
  * Bug fixes (numbers are Red Hat Bugzilla bug ids):
    + 883578 - remote-viewer gets frozen after migration of guest
    with video playback
    + 968931 - Crash in Xspice after closing tab with spice-html5
    + 894421 - Small change in guests resolution results in wrong
    resolution
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Thu Mar 21 2013 sndirsch@suse.com
- Add mibstore.patch, fixes build with xorg-server 1.14
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sun Sep 23 2012 sndirsch@suse.com
- require pkgconfig(spice-protocol) >= 0.12.2
* Sat Sep 22 2012 zaitor@opensuse.org
- Update to version 0.1.0:
  + Minimum required xserver version 1.12.99.901.
  + RENDER support.
  + 8-bit pixmaps.
  + Improved support for memory debugging.
  + Misc bugfixes.
- Drop U_0.0.17-TO-fb038eb.patch, now included in tarball.
* Tue Sep 18 2012 sndirsch@suse.com
- U_0.0.17-TO-fb038eb.patch
  * updated to latest git commit fb038eb in order to fix build on
    xorg-server 1.13
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 0.0.17:
  + options: Turn surfaces and caching on by default
  + Code cleanups
- Add pkgconfig(spice-protocol) BuildRequires: new dependency.
- Use %%x11_abi_videodrv_req instead of static ABI Requiers.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-qxl from xorg-x11-driver-video.
  Initial version: 0.0.13.
